
Containers
==========

.. automodule:: av.container

.. autoclass:: av.container.Container
    :members:


Input Containers
----------------

.. autoclass:: av.container.InputContainer
    :members:


Output Containers
-----------------

.. autoclass:: av.container.OutputContainer
    :members:


Formats
-------

.. automodule:: av.format

    .. autoclass:: ContainerFormat
        :members:
